from setuptools import setup


setup(name='gausbin_probability_distro',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author='Doylee',
      author_email='myemail@something.com',
      zip_safe=False)
